Config class

Constructors

Config(MethodChannel _channel)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

applicationCode() → Future<String?>
changeApplicationCode(String applicationCode) → Future<void>
changeMerchantId(String merchantId) → Future<void>
contactFieldId() → Future<int?>
flutterPluginVersion() → Future<String>
hardwareId() → Future<String>
languageCode() → Future<String>
merchantId() → Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notificationSettings() → Future<NotificationSettings>
sdkVersion() → Future<String>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited