MessageInbox class

Constructors

MessageInbox(MethodChannel _channel, MessageMapper _mapper)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addTag(String messageId, String tag) → Future<void>
fetchMessages() → Future<List<Message>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeTag(String messageId, String tag) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited