Message class

Constructors

Message({required String id, required String campaignId, String? collapseId, required String title, required String body, String? imageUrl, String? imageAltText, required int receivedAt, int? updatedAt, int? expiresAt, List<String>? tags, Map<String, String>? properties, List<ActionModel>? actions})
const

Properties

actions → List<ActionModel>?
final
body → String
final
campaignId → String
final
collapseId → String?
final
expiresAt → int?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
imageAltText → String?
final
imageUrl → String?
final
properties → Map<String, String>?
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
receivedAt → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool
If set to true, the toString method will be overridden to output this instance's props.
no setter
tags → List<String>?
final
title → String
final
updatedAt → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited